@@ -7,7 +7,7 @@ import json
 from . import api as inventree_api
 
 
-INVENTREE_PYTHON_VERSION = "0.9.1"
+INVENTREE_PYTHON_VERSION = "0.10.1"
 
 
 logger = logging.getLogger('inventree')
@@ -141,7 +141,7 @@ class InventreeObject(object):
         if 'pk' in data.keys():
             data.pop('pk')
 
-        response = api.post(cls.URL, data)
+        response = api.post(cls.URL, data, **kwargs)
         
         if response is None:
             logger.error("Error creating new object")
@@ -158,7 +158,7 @@ class InventreeObject(object):
         # By limiting to a single result, we perform a fast query, but get a total number of results
         params['limit'] = 1
 
-        response = api.get(url=cls.URL, params=params, **kwargs)
+        response = api.get(url=cls.URL, params=params)
 
         return response['count']
 
@@ -171,16 +171,13 @@ class InventreeObject(object):
         URL - Base URL
         """
 
-        # Dict of query params to send to the API
-        params = kwargs
-
         # Check if custom URL is present in request arguments
         if 'url' in kwargs:
             url = kwargs.pop('url')
         else:
             url = cls.URL
 
-        response = api.get(url=url, params=params, **kwargs)
+        response = api.get(url=url, params=kwargs)
 
         if response is None:
             return None
@@ -407,12 +404,6 @@ class Attachment(BulkDeleteMixin, InventreeObject):
         return self._api.downloadFile(self.attachment, destination, **kwargs)
 
 
-class Currency(InventreeObject):
-    """ Class representing the Currency database model """
-
-    URL = 'common/currency'
-
-
 class MetadataMixin:
     """Mixin class for models which support a 'metadata' attribute.
 
