@@ -34,9 +34,10 @@ class BuildOrderTest(InvenTreeTestCase):
             build = Build.create(
                 self.api,
                 {
+                    "title": "Automated test build",
                     "part": 25,
                     "quantity": 100,
-                    "reference": f"{n+1}"
+                    "reference": f"BO-{n+1:04d}",
                 }
             )
         else:
@@ -116,3 +117,53 @@ class BuildOrderTest(InvenTreeTestCase):
 
         # All attachments for this Build should have been deleted
         self.assertEqual(len(BuildAttachment.list(self.api, build=build.pk)), 0)
+
+    def test_build_cancel(self):
+        """
+        Test cancelling a build order.
+        """
+
+        n = len(Build.list(self.api))
+
+        # Create a new build order
+        build = Build.create(
+            self.api,
+            {
+                "title": "Automated test build",
+                "part": 25,
+                "quantity": 100,
+                "reference": f"BO-{n+1:04d}"
+            }
+        )
+
+        # Cancel
+        build.cancel()
+
+        # Check status
+        self.assertEqual(build.status, 30)
+        self.assertEqual(build.status_text, 'Cancelled')
+
+    def test_build_complete(self):
+        """
+        Test completing a build order.
+        """
+
+        n = len(Build.list(self.api))
+
+        # Create a new build order
+        build = Build.create(
+            self.api,
+            {
+                "title": "Automated test build",
+                "part": 25,
+                "quantity": 100,
+                "reference": f"BO-{n+1:04d}"
+            }
+        )
+
+        # Complete the build, even though it is not completed
+        build.complete(accept_unallocated=True, accept_incomplete=True)
+
+        # Check status
+        self.assertEqual(build.status, 40)
+        self.assertEqual(build.status_text, 'Complete')
